@@ -142,6 +142,7 @@ class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
             readycandidates = {}
             pendingcandidates = {}
             rejectcandidates = {}
+            invalidated = {}
             done = set()
             # consider both at_revision and from_revision since we want to be
             # able to use magic instructions for files not touched by the
@@ -156,7 +157,12 @@ class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
                     if pstate == 'in-progress':
                         readycandidates[vc.file.path.lower()] = vc.patch
                     elif pstate in ('pending-review', 'reviewed'):
-                        pendingcandidates[vc.file.path.lower()] = vc.patch
+                        if vc in rev.reverse_from_revision:
+                            # patch modified in this revision, should go
+                            # in-progress unless asking for review again
+                            invalidated[vc.file.path.lower()] = vc.patch
+                        else:
+                            pendingcandidates[vc.file.path.lower()] = vc.patch
                 elif (pstate in vc.patch.non_final_states and
                       vc.__regid__ == 'DeletedVersionContent'):
                     rejectcandidates[vc.file.path.lower()] = vc.patch
@@ -164,6 +170,7 @@ class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
             interestingwords.update(readycandidates)
             interestingwords.update(pendingcandidates)
             interestingwords.update(rejectcandidates)
+            interestingwords.update(invalidated)
             # search for instruction
             for line in rev.description.splitlines():
                 words = [w.lower() for w in re.findall('[-\.\w]+', line.strip())
@@ -194,6 +201,18 @@ class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
                     self.ensure_wont_be_deleted(patch)
                     # XXX search source repository changeset id
                     #patch.set_relations(applied_at=rev)
+                elif words[1] in ('ready', 'pending') and words[0] in invalidated:
+                    # re-asking for review of a patch we're modifying:
+                    # either the patch is already pending-review and stays
+                    # there, or it was reviewed and should go back to
+                    # pending-review
+                    patch = invalidated.pop(words[0])
+                    if patch.cw_adapt_to('IWorkflowable').state == 'reviewed':
+                        fire(patch, 'ask review', u'review asked by %s in %s' % (
+                                     rev.author, rev.dc_title()))
+            for patch in invalidated.itervalues():
+                fire(patch, 'ask rework', u'modified by %s in %s' % (
+                    rev.author, rev.dc_title()))
 
     def ensure_wont_be_deleted(self, patch):
         op = MarkPatchAsDeletedOp.get_instance(self.session)
