@@ -29,7 +29,7 @@ rejected   = pwf.add_state(_('rejected'))
 folded     = pwf.add_state(_('folded'))
 deleted    = pwf.add_state(_('deleted'))
 
-pwf.add_transition(_('ask review'), inprogress, pending,
+pwf.add_transition(_('ask review'), (inprogress, reviewed), pending,
                    ('managers', 'users',)) # XXX patch owner only?
 pwf.add_transition(_('accept'), (inprogress, pending), reviewed,
                    ('managers', 'committers', 'reviewers',),
