@@ -78,10 +78,10 @@ class PatchCreationHooksTC(CubicWebTC):
                 byfile.setdefault(iter(files).next(), []).append(patch)
             else:
                 bypatch[patch] = files
-        self.assertEqual(len(byfile), 4, byfile)
+        self.assertEqual(len(byfile), 5, byfile)
         # bypatch check we're correctly following renaming
         self.assertEqual(len(bypatch), 1)
-        self.assertEqual(len(patches), 7)
+        self.assertEqual(len(patches), 8)
 
         folded = bypatch.keys()[0]
         self.assertEqual(folded.cw_adapt_to('IWorkflowable').state, 'folded')
@@ -109,8 +109,17 @@ class PatchCreationHooksTC(CubicWebTC):
         self.assertEqual(history[-1].new_state.name, 'rejected')
         self.assertEqual(revnums(patch3_2), [7, 10, 15])
 
+        self.assertEqual(len(byfile['patch4.diff']), 1)
+        patch4 = byfile['patch4.diff'][0]
+        self.assertEqual(patch4.cw_adapt_to('IWorkflowable').state, 'in-progress')
+        self.assertEqual(revnums(patch4), [17, 18, 19])
+        history = patch4.cw_adapt_to('IWorkflowable').workflow_history
+        self.assertEqual(history[-1].previous_state.name, 'pending-review')
+        self.assertEqual(history[-1].new_state.name, 'in-progress')
+
         self.assertTrue(patch3_2.nosy_list)
-        self.assertEqual(len(MAILBOX), 3)
+        self.assertTrue(patch4.nosy_list)
+        self.assertEqual(len(MAILBOX), 6, MAILBOX)
         self.assertEqual(MAILBOX[0].subject, '[patch repository] patch pending-review: patch3.diff')
         self.assertEqual(MAILBOX[0].recipients, ['admin@cwo'])
         self.assertMultiLineEqual(MAILBOX[0].content, u'''
@@ -139,6 +148,33 @@ rejected by Sylvain Th\xe9nault <sylvain.thenault@logilab.fr> in #15:a5c0568f81d
 
 url: http://testing.fr/cubicweb/patch/%s\n''' % patch3_2.eid)
 
+        self.assertEqual(MAILBOX[3].subject, '[patch repository] patch pending-review: patch4.diff')
+        self.assertEqual(MAILBOX[3].recipients, ['admin@cwo'])
+        self.assertMultiLineEqual(MAILBOX[3].content, u'''
+cubicweb changed status from <in-progress> to <pending-review> for entity
+'patch4.diff'
+
+review asked by Julien Cristau <julien.cristau@logilab.fr> in #17:2f2bad1f3f12
+
+url: http://testing.fr/cubicweb/patch/%s\n''' % patch4.eid)
+
+        self.assertEqual(MAILBOX[4].subject, '[patch repository] patch assigned: patch4.diff')
+        self.assertEqual(MAILBOX[4].recipients, ['admin@cwo'])
+        self.assertMultiLineEqual(MAILBOX[4].content, u'''
+You have been assigned for review of patch patch4.diff
+
+url: http://testing.fr/cubicweb/patch/%s\n''' % patch4.eid)
+
+        self.assertEqual(MAILBOX[5].subject, '[patch repository] patch in-progress: patch4.diff')
+        self.assertEqual(MAILBOX[5].recipients, ['admin@cwo'])
+        self.assertMultiLineEqual(MAILBOX[5].content, u'''
+cubicweb changed status from <pending-review> to <in-progress> for entity
+'patch4.diff'
+
+modified by Julien Cristau <julien.cristau@logilab.fr> in #19:650cce0df5e2
+
+url: http://testing.fr/cubicweb/patch/%s\n''' % patch4.eid)
+
         MAILBOX[:] = ()
         req = self.request()
         req.create_entity('Task', title=u'todo', reverse_has_activity=patch3_2)
@@ -164,6 +200,10 @@ url: http://testing.fr/cubicweb/task/%s\n''' % done.eid)
         self.commit()
 
         MAILBOX[:] = ()
+
+        patch3_2.cw_adapt_to('IWorkflowable').fire_transition('accept')
+        self.commit()
+
         # fake revision from the main repo of our patch repo
         atrevision = [self.session.entity_from_eid(patch3_2.revisions[-1].eid)]
         revision = mock_object(repository=self.vcsrepo,
@@ -182,11 +222,13 @@ url: http://testing.fr/cubicweb/task/%s\n''' % done.eid)
         self.assertEqual(patch3_2.cw_adapt_to('IWorkflowable').state, 'applied')
         #self.assertEqual(patch3_2.applied_at[0].eid, patch3_2.revisions[-1].rev.eid) XXX
 
-        self.assertEqual(len(MAILBOX), 1, MAILBOX)
-        self.assertEqual(MAILBOX[0].subject, '[patch repository] patch applied: patch3.diff')
+        self.assertEqual(len(MAILBOX), 2, MAILBOX)
+        self.assertEqual(MAILBOX[0].subject, '[patch repository] patch reviewed: patch3.diff')
+        self.assertEqual(MAILBOX[1].subject, '[patch repository] patch applied: patch3.diff')
         self.assertEqual(MAILBOX[0].recipients, ['admin@cwo'])
-        self.assertMultiLineEqual(MAILBOX[0].content, u'''
-admin changed status from <pending-review> to <applied> for entity
+        self.assertEqual(MAILBOX[1].recipients, ['admin@cwo'])
+        self.assertMultiLineEqual(MAILBOX[1].content, u'''
+admin changed status from <reviewed> to <applied> for entity
 'patch3.diff'
 
 applied by syt
