@@ -82,7 +82,7 @@ class PatchReviewWorkflowTC(CubicWebTC):
             self.commit()
             patch.cw_clear_all_caches()
             self.assertListEqual(sorted(x[0] for x in self.action_submenu(req, rset, 'workflow')),
-                                 ['ask rework', 'fold', 'view history', 'view workflow'])
+                                 [u'ask review', u'ask rework', u'fold', u'view history', u'view workflow'])
             # create a task and mark task2 as done
             task3eid = req.create_entity(
                 'Task', reverse_has_activity=patch, title=u'todo 3').eid
@@ -93,7 +93,7 @@ class PatchReviewWorkflowTC(CubicWebTC):
             req = self.request()
             rset = req.execute('Any X WHERE X eid %(x)s', {'x': self.patch1eid})
             self.assertListEqual(sorted(x[0] for x in self.action_submenu(req, rset, 'workflow')),
-                                 ['apply', 'ask rework', 'fold', 'reject', 'view history', 'view workflow'])
+                                 ['apply', 'ask review', 'ask rework', 'fold', 'reject', 'view history', 'view workflow'])
             patch = rset.get_entity(0, 0)
             patch.cw_adapt_to('IWorkflowable').fire_transition('apply')
             self.commit()
