@@ -22,8 +22,7 @@ from logilab.mtconverter import xml_escape
 
 from cubicweb.selectors import (is_instance, relation_possible,
                                 score_entity, match_form_params)
-from cubicweb.view import EntityView
-from cubicweb.uilib import js
+from cubicweb import tags, uilib, view
 from cubicweb.web import uicfg, component, form, formwidgets as wdg
 from cubicweb.web.views import (workflow, idownloadable, ajaxedit,
                                 forms, formrenderers)
@@ -48,7 +47,7 @@ _affk.tag_object_of(('*', 'has_activity', 'Task'),
                     {'widget': wdg.HiddenInput})
 
 
-class AddActivityFormView(form.FormViewMixIn, EntityView):
+class AddActivityFormView(form.FormViewMixIn, view.EntityView):
     __regid__ = 'vcreview.addactivityform'
     __select__ = (relation_possible('has_activity', 'subject', 'Task', 'add')
                   | match_form_params('etype'))
@@ -65,8 +64,8 @@ class AddActivityFormView(form.FormViewMixIn, EntityView):
         self._cw.add_js(('cubicweb.edition.js', 'cubes.vcreview.js'))
         activity = self._cw.vreg['etypes'].etype_class('Task')(self._cw)
         activity.eid = self._cw.varmaker.next()
-        okjs = js.addActivity(container.eid, not container.has_eid(),
-                              self.cw_extra_kwargs.get('context'))
+        okjs = uilib.js.addActivity(container.eid, not container.has_eid(),
+                                    self.cw_extra_kwargs.get('context'))
         canceljs = "jQuery('#activity%sSlot').remove()" % container.eid
         form, formvalues = ajaxedit.ajax_composite_form(
             container, activity, 'has_activity', okjs, canceljs,
@@ -147,26 +146,7 @@ ActivityComponent.order = 20
 comment.CommentSectionVComponent.order = 30
 
 
-class TaskDoneForm(forms.CompositeEntityForm):
-    __regid__ = 'taskdone'
-    form_renderer_id = 'onebutton'
-    form_buttons = [wdg.SubmitButton(label=_('mark as done'))]
-    cssclass = 'inline'
-    @property
-    def domid(self):
-        return 'taskdone%s' % self.edited_entity.eid
-
-
-class MyFormRenderer(formrenderers.FormRenderer):
-    __regid__ = 'onebutton'
-    display_progress_div = False
-
-    def render_buttons(self, w, form):
-        for button in form.form_buttons:
-            w(button.render(form))
-
-
-class TaskStateView(form.FormViewMixIn, EntityView):
+class TaskStateView(form.FormViewMixIn, view.EntityView):
     __regid__ = 'vcreview.task-state'
     __select__ = is_instance('Task')
 
@@ -180,38 +160,23 @@ class TaskStateView(form.FormViewMixIn, EntityView):
             if transition.name == 'done':
                 break
         else:
-            return # task workflow changed or no permission to go through the transtion
-        form = self.get_form(entity, transition)
-        form.render(w=self.w)
-
-    def get_form(self, entity, transition, **kwargs):
-        form = self._cw.vreg['forms'].select(
-            'taskdone', self._cw, entity=entity, transition=transition,
-            redirect_path=self._cw.relative_path(), **kwargs)
-        trinfo = self._cw.vreg['etypes'].etype_class('TrInfo')(self._cw)
-        trinfo.eid = self._cw.varmaker.next()
-        subform = self._cw.vreg['forms'].select(
-            'edition', self._cw, entity=trinfo, mainform=False,
-            display_fields=[('wf_info_for', 'subject'),
-                            ('by_transition', 'subject')])
-        subform.field_by_name('wf_info_for', 'subject').value = entity.eid
-        trfield = subform.field_by_name('by_transition', 'subject')
-        trfield.widget = wdg.HiddenInput()
-        trfield.value = transition.eid
-        form.add_subform(subform)
-        return form
+            return # task workflow changed or no permission to go through the transition
+        def change_state(req, eid):
+            entity = req.entity_from_eid(eid)
+            entity.cw_adapt_to('IWorkflowable').fire_transition('done')
+        url = self._cw.user_callback(change_state, (entity.eid,))
+        self.w(tags.input(type='button', onclick=url, value=self._cw._('mark as done')))
 
 
-class TaskLinkView(form.FormViewMixIn, EntityView):
+class TaskLinkView(form.FormViewMixIn, view.EntityView):
     __regid__ = 'vcreview.task-link'
     __select__ = is_instance('Task')
     def entity_call(self, entity):
         self.w(entity.view('incontext'))
-        if not self._cw.json_request and \
-               entity.reverse_has_activity[0].__regid__ == 'InsertionPoint':
+        if entity.reverse_has_activity[0].__regid__ == 'InsertionPoint' \
+               and self._cw.form.get('vid') == 'vcreview.patch.tab_main':
             ip = entity.reverse_has_activity[0]
             purl = ip.parent.absolute_url()
-            if purl != self._cw.url(includeparams=False):
-                url = u'%s#%s%s' % (purl, COMPONENT_CONTEXT, ip.eid)
-                self.w(u' (<a href="%s">%s</a>)' % (url, self._cw._('see in context')))
+            url = u'%s#%s%s' % (purl, COMPONENT_CONTEXT, ip.eid)
+            self.w(u' (<a href="%s">%s</a>)' % (url, self._cw._('see in context')))
 
