@@ -93,8 +93,8 @@ class DVCFileVersion(EntityView):
     __select__ = is_instance('DeletedVersionContent', 'VersionContent')
 
     def entity_call(self, entity):
-        self.w(tags.a(self._cw._(u'%(file)s (revision %(revnum)s)') % {
-            'file':entity.dc_title(), 'revnum': entity.revision},
+        self.w(tags.a(self._cw._(u'%(file)s (at %(rev)s)') % {
+            'file':entity.dc_title(), 'rev': entity.rev.dc_title()},
                       href=entity.absolute_url()))
 
 class DVCCommentCount(EntityView):
@@ -126,7 +126,7 @@ class VCPrimaryView(vcsfile.VCPrimaryView):
 
     def render_entity_title(self, entity):
         title = self._cw._('Revision %(revision)s of patch %(file)s') % {
-            'revision': entity.revision, 'file': entity.patch.view('oneline')}
+            'revision': entity.dc_title(), 'file': entity.patch.view('oneline')}
         self.w('<h1>%s</h1>' % title)
         vcsfile.render_entity_summary(self, entity)
 
