@@ -75,12 +75,14 @@ class PatchesTable(tableview.TableView):
         super(PatchesTable, self).call(cellvids={2: 'vcreview.patch.reviewers', 3: 'vcreview.patch.committers'},
                                        **kwargs)
 
-    def label_column_2(self):
-        return self._cw._('patch_reviewer')
-    def label_column_3(self):
-        return self._cw._('patch_committer')
-    def label_column_6(self):
-        return self._cw.__('Transition_plural').lower()
+    def column_label(self, colidx, default, translate_func=None):
+        if colidx == 2:
+            return self._cw._('patch_reviewer')
+        if colidx == 3:
+            return self._cw._('patch_committer')
+        if colidx == 6:
+            return self._cw.__('Transition_plural').lower()
+        return super(PatchesTable, self).column_label(colidx, default, translate_func)
 
 
 class PatchReviewer(view.EntityView):
